@@ -1,12 +1,12 @@
 package NexTrieve::Collection::Index;
 
-# Make sure we do everything by the book
 # Set modules to inherit from
 # Set version information
+# Make sure we do everything by the book from now on
 
+@ISA = qw(NexTrieve);
+$VERSION = '0.38';
 use strict;
-@NexTrieve::Collection::Index::ISA = qw(NexTrieve);
-$NexTrieve::Collection::Index::VERSION = '0.37';
 
 # Use all the other NexTrieve modules that we need always
 
@@ -14,7 +14,7 @@ use NexTrieve::Daemon ();
 use NexTrieve::Resource ();
 use NexTrieve::Search ();
 
-# Return true value for use
+# Satisfy -require-
 
 1;
 
