@@ -1,12 +1,12 @@
 package NexTrieve::Docseq;
 
-# Make sure we do everything by the book
 # Set modules to inherit from
 # Set version information
+# Make sure we do everything by the book from now on
 
+@ISA = qw(NexTrieve);
+$VERSION = '0.38';
 use strict;
-@NexTrieve::Docseq::ISA = qw(NexTrieve);
-$NexTrieve::Docseq::VERSION = '0.37';
 
 # Use all the Perl modules needed here
 
@@ -44,7 +44,7 @@ my %dispatch; %dispatch = (
  SCALAR		=> sub {${$_[0]}},
 );
 
-# Return true value for use
+# Satisfy -require-
 
 1;
 
