@@ -1,18 +1,18 @@
 package NexTrieve::Hitlist;
 
-# Make sure we do everything by the book
 # Set modules to inherit from
 # Set version information
+# Make sure we do everything by the book from now on
 
+@ISA = qw(NexTrieve);
+$VERSION = '0.38';
 use strict;
-@NexTrieve::Hitlist::ISA = qw(NexTrieve);
-$NexTrieve::Hitlist::VERSION = '0.37';
 
 # Use all the submodules that we always need
 
 use NexTrieve::Hitlist::Hit ();
 
-# Return true value for use
+# Satisfy -require-
 
 1;
 
