@@ -1,14 +1,14 @@
 package NexTrieve::Hitlist::Hit;
 
-# Make sure we do everything by the book
 # Set modules to inherit from
 # Set version information
+# Make sure we do everything by the book from now on
 
+@ISA = qw(NexTrieve); # nothing from NexTrieve::Hitlist
+$VERSION = '0.38';
 use strict;
-@NexTrieve::Hitlist::Hit::ISA = qw(NexTrieve); # nothing from NexTrieve::Hitlist
-$NexTrieve::Hitlist::Hit::VERSION = '0.37';
 
-# Return true value for use
+# Satisfy -require-
 
 1;
 
