@@ -1,18 +1,18 @@
 package NexTrieve::Query;
 
-# Make sure we do everything by the book
 # Set modules to inherit from
 # Set version information
+# Make sure we do everything by the book from now on
 
+@ISA = qw(NexTrieve);
+$VERSION = '0.38';
 use strict;
-@NexTrieve::Query::ISA = qw(NexTrieve);
-$NexTrieve::Query::VERSION = '0.37';
 
 # Initialize the list of texttype keys
 
 my @texttypekey = qw(weight);
 
-# Return true value for use
+# Satisfy -require-
 
 1;
 
